from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

sensors = SchLib(tool=SKIDL).add_parts(*[
        Part(name='40PC015G',dest=TEMPLATE,tool=SKIDL,keywords='gage gauge pressure sensor',description='Gauge pressure sensor, 0 to 250PSI, 5V supply, 0.2% accuracy, integrated signal conditioning, excellent media compatibility',ref_prefix='U',num_units=1,do_erc=True,aliases=['40PC100G', '40PC150G', '40PC250G'],pins=[
            Pin(num='1',name='Vcc',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='A1101ELHL',dest=TEMPLATE,tool=SKIDL,keywords='hall switch',description='Hall effect switch, unipolar, Bop=340G, Brp=240G, -40C to +125C',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['A1101LLHL', 'A1102ELHL', 'A1102LLHL', 'A1103ELHL', 'A1103LLHL', 'A1104LLHL', 'A1106LLHL'],pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='A1301KLHLT-T',dest=TEMPLATE,tool=SKIDL,keywords='hall switch',description='Linear Hall Effect Sensor, SOT-23W',ref_prefix='U',num_units=1,fplist=['SOT*'],do_erc=True,aliases=['A1302ELHLT-T', 'A1302KLHLT-T'],pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='A1301KUA-T',dest=TEMPLATE,tool=SKIDL,keywords='hall switch',description='Linear Hall Effect Sensor, SIP 3pin',ref_prefix='U',num_units=1,do_erc=True,aliases=['A1301EUA-T', 'A1302KUA-T'],pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='AD8418',dest=TEMPLATE,tool=SKIDL,keywords='current sense amplifier shunt high side bidirectional',description='Bidirectional zero-drift current sense amplifier, 20V/V',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-IN',do_erc=True),
            Pin(num='2',name='V-',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VR2',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VR1',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='+IN',do_erc=True)]),
        Part(name='AS5045B',dest=TEMPLATE,tool=SKIDL,keywords='Magnetic Hall Encoder',description='Magnetic Position Sensor, 12-bit, PWM Output, ABI Output, SPI Interface',ref_prefix='U',num_units=1,fplist=['SSOP*16_5.3x6.2mm*Pitch0.65mm*'],do_erc=True,pins=[
            Pin(num='1',name='MagINCn',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='2',name='MagDECn',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='3',name='A',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='B',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='I',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='PDIO',do_erc=True),
            Pin(num='9',name='DO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='CLK',do_erc=True),
            Pin(num='11',name='CSn',do_erc=True),
            Pin(num='12',name='PWM',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='14',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='15',name='VDD3V3',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VDD5V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='AS5048A',dest=TEMPLATE,tool=SKIDL,keywords='sensor magnetic hall position rotation spi',description='Magnetic position sensor, 14-bit, PWM output, SPI Interface',ref_prefix='U',num_units=1,fplist=['SSOP*'],do_erc=True,pins=[
            Pin(num='1',name='~CSn',do_erc=True),
            Pin(num='2',name='CLK',do_erc=True),
            Pin(num='3',name='MISO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='MOSI',do_erc=True),
            Pin(num='5',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='VDD5V',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VDD3V',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='PWM',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='AS5048B',dest=TEMPLATE,tool=SKIDL,keywords='sensor magnetic hall position rotation i2c',description='Magnetic position sensor, 14-bit, PWM output, I2C Interface',ref_prefix='U',num_units=1,fplist=['SSOP*'],do_erc=True,pins=[
            Pin(num='1',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='SCL',do_erc=True),
            Pin(num='3',name='A2',do_erc=True),
            Pin(num='4',name='A1',do_erc=True),
            Pin(num='5',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='VDD5V',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VDD3V',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='PWM',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='AS5055A',dest=TEMPLATE,tool=SKIDL,keywords='sensor magnetic hall position rotation spi',description='Magnetic position sensor, 12-bit, SPI interface',ref_prefix='U',num_units=1,fplist=['QFN*'],do_erc=True,aliases=['AS5050A'],pins=[
            Pin(num='1',name='MOSI',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='MISO',do_erc=True),
            Pin(num='3',name='SCK',do_erc=True),
            Pin(num='4',name='~SS',do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='9',name='TEST',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='~EN_INT',do_erc=True),
            Pin(num='11',name='VDDp',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='WM',do_erc=True),
            Pin(num='15',name='~INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='17',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='BD1020HFV',dest=TEMPLATE,tool=SKIDL,keywords='Temperature sensor',description='Analog Ouput Temperature Sensor',ref_prefix='U',num_units=1,fplist=['HVSOF5*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='PG',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='BMP085',dest=TEMPLATE,tool=SKIDL,keywords='Digital Barometer',description='19-Bit Digital Barometer, LCC-8',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='EOC',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='SCL',do_erc=True),
            Pin(num='7',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='XCLR',do_erc=True)]),
        Part(name='C12880MA',dest=TEMPLATE,tool=SKIDL,keywords='spectrometer',description='Micro spectrometer 340 to 850nm resolution 15nm',ref_prefix='U',num_units=1,fplist=['C12880*'],do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='CLK',do_erc=True),
            Pin(num='5',name='CASE',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='ST',do_erc=True),
            Pin(num='7',name='TRG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='9',name='EOS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='VIDEO',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='DHT11',dest=TEMPLATE,tool=SKIDL,keywords='digital temperature humidity sensor',description='- Temperature and humidity module',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VCC',do_erc=True),
            Pin(num='2',name='IO',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='Flir_LEPTON',dest=TEMPLATE,tool=SKIDL,keywords='LWIR camera',description='LWIR camera 8 to 14um 80x60 pixel',ref_prefix='U',num_units=1,fplist=['105028-1001*', '105028-2011*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GPIO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='GPIO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='GPIO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='GPIO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VDDC',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='SPI_MOSI',do_erc=True),
            Pin(num='21',name='SCL',do_erc=True),
            Pin(num='31',name='MIPI_DATA_N',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='SPI_MISO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='MIPI_DATA_P',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='SPI_CLK',do_erc=True),
            Pin(num='23',name='PWR_DWN_L',do_erc=True),
            Pin(num='14',name='SPI_CS_L',do_erc=True),
            Pin(num='24',name='RESET_L',do_erc=True),
            Pin(num='15',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='MASTER_CLK',do_erc=True),
            Pin(num='17',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='27',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='MIPI_CLK_N',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='MIPI_CLK_P',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='INA138',dest=TEMPLATE,tool=SKIDL,keywords='current sensor shunt monitor',description='Unipolar high-side current shunt monitor, 60V common mode',ref_prefix='U',num_units=1,fplist=['SOT-23-*'],do_erc=True,aliases=['INA168'],pins=[
            Pin(num='1',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='+IN',do_erc=True),
            Pin(num='5',name='-IN',do_erc=True)]),
        Part(name='INA193',dest=TEMPLATE,tool=SKIDL,keywords='Current sensor shunt monitor high low side',description='100V/V Current shunt monitor with independent supply, -16V to +80V common mode range',ref_prefix='U',num_units=1,fplist=['SOT-23'],do_erc=True,aliases=['INA194', 'INA195'],pins=[
            Pin(num='1',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='+IN',do_erc=True),
            Pin(num='4',name='-IN',do_erc=True),
            Pin(num='5',name='V+',func=Pin.PWRIN,do_erc=True)]),
        Part(name='INA196',dest=TEMPLATE,tool=SKIDL,keywords='Current sensor shunt monitor high low side',description='100V/V Current shunt monitor with independent supply, -16V to +80V common mode range',ref_prefix='U',num_units=1,fplist=['SOT-23'],do_erc=True,aliases=['INA197', 'INA198'],pins=[
            Pin(num='1',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='+IN',do_erc=True),
            Pin(num='5',name='-IN',do_erc=True)]),
        Part(name='INA282',dest=TEMPLATE,tool=SKIDL,keywords='current monitor shunt sensor bidirectional high low side common mode',description='100V/V High accuracy, wide common-mode range bidirectional current shunt monitor',ref_prefix='U',num_units=1,do_erc=True,aliases=['INA286', 'INA283', 'INA284', 'INA285'],pins=[
            Pin(num='1',name='-IN',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='REF2',do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='OUT',do_erc=True),
            Pin(num='6',name='V+',do_erc=True),
            Pin(num='7',name='REF1',do_erc=True),
            Pin(num='8',name='+IN',do_erc=True)]),
        Part(name='KTY81',dest=TEMPLATE,tool=SKIDL,keywords='silicon temperature sensors',description='KTY81 series silicon temperature sensors',ref_prefix='TH',num_units=1,fplist=['TO?92*', 'SOD70*'],do_erc=True,aliases=['KT100', 'KTY10'],pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='KTY82',dest=TEMPLATE,tool=SKIDL,keywords='silicon temperature sensors',description='KTY82 series silicon temperature sensors, SOT-23',ref_prefix='TH',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='KTY83',dest=TEMPLATE,tool=SKIDL,keywords='silicon temperature sensor diode',description='KTY84 series silicon temperature sensors, polarized, SOD68',ref_prefix='TH',num_units=1,fplist=['DO?34*', 'SOD68*'],do_erc=True,aliases=['KTY84'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='KTY85',dest=TEMPLATE,tool=SKIDL,keywords='silicon temperature sensor diode',description='KTY85 series silicon temperature sensors, polarized, SOD80',ref_prefix='TH',num_units=1,fplist=['SOD80*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='L3G4200D',dest=TEMPLATE,tool=SKIDL,keywords='3-Axis MEMS Gyroscope',description='16-bit 3 Axis Digital MEMS Gyroscope, LGA-16',ref_prefix='U',num_units=1,fplist=['LGA*'],do_erc=True,pins=[
            Pin(num='1',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SCL/SPC',do_erc=True),
            Pin(num='3',name='SDA/SDI/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='SDO/SA0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='CS',do_erc=True),
            Pin(num='6',name='DRDY/INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='PLLFILT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='RES(VDD)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='L3GD20',dest=TEMPLATE,tool=SKIDL,keywords='3-Axis MEMS Gyroscope',description='16-bit 3 Axis Digital MEMS Gyroscope, LGA-16',ref_prefix='U',num_units=1,fplist=['LGA*'],do_erc=True,pins=[
            Pin(num='1',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SCL/SPC',do_erc=True),
            Pin(num='3',name='SDA/SDI/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='SDO/SA0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='CS',do_erc=True),
            Pin(num='6',name='DRDY/INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='RES(GND)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='RES(CAP)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='RES(VDD)',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LA25-P',dest=TEMPLATE,tool=SKIDL,keywords='LEM current transducer',description='LA 55-P Current transducer',ref_prefix='U',num_units=1,fplist=['LEM_LA25-P'],do_erc=True,aliases=['LA55-P', 'LA100-P'],pins=[
            Pin(num='1',name='M',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='-',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='+',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LIS2DH',dest=TEMPLATE,tool=SKIDL,keywords='3-axis accelerometer spi mems',description='3-Axis Accelerometer, 2/4/8/16g range, I2C/SPI interface',ref_prefix='U',num_units=1,fplist=['LGA-*_2x2mm_Pitch0.35mm*'],do_erc=True,pins=[
            Pin(num='1',name='SCL/SPC',do_erc=True),
            Pin(num='2',name='SDA/SDI',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='SA0/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='~CS',do_erc=True),
            Pin(num='5',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='Vdd_IO',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LIS2HH12',dest=TEMPLATE,tool=SKIDL,keywords='3-axis accelerometer spi mems',description='3-Axis Accelerometer, 2/4/8g range, I2C/SPI interface',ref_prefix='U',num_units=1,fplist=['LGA*2x2mm*Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='SCL/SPC',do_erc=True),
            Pin(num='2',name='~CS',do_erc=True),
            Pin(num='3',name='SA0/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='SDA/SDI',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RES',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='Vdd_IO',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='INT1',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='LIS331HH',dest=TEMPLATE,tool=SKIDL,keywords='3-axis accelerometer spi i2c mems',description='3-Axis Accelerometer, 6/12/24g range, 1000Hz, I2C and SPI interface',ref_prefix='U',num_units=1,fplist=['LGA-*_3x3mm_Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='SCL/SPC',do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='SDA/SDI',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='SA0/SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='~CS',do_erc=True),
            Pin(num='9',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM35-D',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Precision centigrade temperature sensor, SOIC-8 package',ref_prefix='U',num_units=1,fplist=['SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='+VS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM35-LP',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Precision centigrade temperature sensor, TO-92 package',ref_prefix='U',num_units=1,fplist=['TO-92*'],do_erc=True,pins=[
            Pin(num='1',name='+VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LM35-NEB',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Precision centigrade temperature sensor, TO-220 package',ref_prefix='U',num_units=1,fplist=['TO-220*'],do_erc=True,pins=[
            Pin(num='1',name='+VS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='LM73',dest=TEMPLATE,tool=SKIDL,keywords='digital temperature sensor',description='11 to 14 Bit digital temperature sensor with 2 wire interface, SOT23-6',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,aliases=['LM73-1'],pins=[
            Pin(num='1',name='ADDR',do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='SMBCLK',do_erc=True),
            Pin(num='5',name='~ALERT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='SMBDAT',func=Pin.BIDIR,do_erc=True)]),
        Part(name='LMT84DCK',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor ntc',description='Analog temperature sensor, NTC, 0.4C accuracy, -5.5mV/C, -50C to +150C, 1.5 to 5.5V, SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC-70-*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LMT85DCK',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor ntc',description='Analog temperature sensor, NTC, 0.3C accuracy, -8.2mV/C, -50C to +150C, 1.8 to 5.5V, SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC-70-*'],do_erc=True,pins=[
            Pin(num='1',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LMT86DCK',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor ntc',description='Analog temperature sensor, NTC, 0.25C accuracy, -10.9mV/C, -50C to +150C, 2.2 to 5.5V, SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC-70-*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Vdd',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LMT87DCK',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor ntc',description='Analog temperature sensor, NTC, 0.3C accuracy, -13.6mV/C, -50C to +150C, 2.7 to 5.5V, SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC-70-*'],do_erc=True,pins=[
            Pin(num='1',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Vdd',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LSM303D',dest=TEMPLATE,tool=SKIDL,keywords='Accelerometer Magnetometer MEMS',description='I2C/SPI, 3D Accelerometer and 3D Magnetometer',ref_prefix='U',num_units=1,fplist=['LGA*'],do_erc=True,pins=[
            Pin(num='1',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SETC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='SETP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='SCL/SPC',do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='SDA/SDI/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='SDO/SAO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='CS',do_erc=True),
            Pin(num='9',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='C1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LSM303DLHC',dest=TEMPLATE,tool=SKIDL,keywords='Accelerometer Magnetometer MEMS',description='I2C, 3D Accelerometer and 3D Magnetometer',ref_prefix='U',num_units=1,fplist=['LGA*'],do_erc=True,pins=[
            Pin(num='1',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SCL',do_erc=True),
            Pin(num='3',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='C1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='9',name='DRDY',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='SETP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='SETC',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LSM9DS1',dest=TEMPLATE,tool=SKIDL,keywords='I2C SPI IMU accelerometer gyroscope magnetometer',description='I2C SPI 9 axis IMU accelerometer gyroscope magnetometer',ref_prefix='U',num_units=1,fplist=['LGA*3x3.5mm*Pitch0.43mm*'],do_erc=True,pins=[
            Pin(num='1',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SCL/SPC',do_erc=True),
            Pin(num='3',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='SDA/SDI/SDO',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='SDO_A/G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='SDO_M',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='CS_A/G',do_erc=True),
            Pin(num='8',name='CS_M',do_erc=True),
            Pin(num='9',name='DRDY_M',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='INT_M',func=Pin.OUTPUT,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='INT1_A/G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='CAP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='INT2_A/G',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='DEN_A/G',do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='RES',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='C1',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='RES',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='RES',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='RES',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RES',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='LV25-P',dest=TEMPLATE,tool=SKIDL,keywords='Voltage transducer',description='LEM Voltage transducer LV 25-P',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='HV+',do_erc=True),
            Pin(num='3',name='HV-',do_erc=True),
            Pin(num='4',name='M',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='V-',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MAX31855',dest=TEMPLATE,tool=SKIDL,keywords='Thermocouple Converter',description='Cold-Junction Compensated Thermocouple-to-Digital Converter',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='T-',do_erc=True),
            Pin(num='3',name='T+',do_erc=True),
            Pin(num='4',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='SCK',do_erc=True),
            Pin(num='6',name='~CS',do_erc=True),
            Pin(num='7',name='SO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='NC',do_erc=True)]),
        Part(name='MCP9501',dest=TEMPLATE,tool=SKIDL,keywords='Temperature Switch sensor',description='Temperature Switch with Selectable Hysteresis, Open-Drain, Active-Low Output (Cold Option), SOT-23-5',ref_prefix='U',num_units=1,fplist=['SOT?23*'],do_erc=True,aliases=['MCP9503'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Hyst',do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Out',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='MCP9502',dest=TEMPLATE,tool=SKIDL,keywords='Temperature Switch sensor',description='Temperature Switch with Selectable Hysteresis, Push-Pull, Active-High Output (Cold Option), SOT-23-5',ref_prefix='U',num_units=1,fplist=['SOT?23*'],do_erc=True,aliases=['MCP9504'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Hyst',do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='Out',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='MCP9700AT-E/LT',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Low power, analog thermistor temperature sensor, ±4C accuracy, -40C to +150C, in SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC-70-5*'],do_erc=True,aliases=['MCP9700AT-H/LT', 'MCP9700T-E/LT', 'MCP9700T-H/LT'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='MCP9700T-H/TT',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Low power, analog thermistor temperature sensor, ±4C accuracy, -40C to +150C, in SOT-23-3 package',ref_prefix='U',num_units=1,fplist=['SOT-23-3*'],do_erc=True,aliases=['MCP9700T-E/TT', 'MCP9700AT-H/TT', 'MCP9700AT-E/TT'],pins=[
            Pin(num='1',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MMA8653FCR1',dest=TEMPLATE,tool=SKIDL,keywords='Accelerometer I2C',description='3-Axis 10-bit Digital Accelerometer with I2C interface',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='SCL',do_erc=True),
            Pin(num='3',name='INT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='BYP',do_erc=True),
            Pin(num='5',name='INT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vddio',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='SDA',do_erc=True)]),
        Part(name='MP45DT02',dest=TEMPLATE,tool=SKIDL,keywords='MEMS Microphone',description='MEMS Omnidirectional Digital Microphone, HLGA-6',ref_prefix='U',num_units=1,fplist=['HLGA*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='LR',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='CLK',do_erc=True),
            Pin(num='5',name='DOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MPU-6000',dest=TEMPLATE,tool=SKIDL,keywords='mems',description='InvenSense 6-Axis Motion Sensor, Gyroscope, Accelerometer, I2C/SPI',ref_prefix='U',num_units=1,fplist=['QFN-24*4x4mm_Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='CLKIN',do_erc=True),
            Pin(num='6',name='AUX_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AUX_SCL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='~CS',do_erc=True),
            Pin(num='9',name='AD0/MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='REGOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='CPOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='FSYNC',do_erc=True),
            Pin(num='12',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='SCL/SCLK',do_erc=True),
            Pin(num='24',name='SDA/MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MPU-6050',dest=TEMPLATE,tool=SKIDL,keywords='mems',description='InvenSense 6-Axis Motion Sensor, Gyroscope, Accelerometer, I2C',ref_prefix='U',num_units=1,fplist=['QFN-24*4x4mm_Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='CLKIN',do_erc=True),
            Pin(num='6',name='AUX_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AUX_SCL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='AD0',do_erc=True),
            Pin(num='10',name='REGOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='CPOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='FSYNC',do_erc=True),
            Pin(num='12',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='SCL',do_erc=True),
            Pin(num='24',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MPU-9150',dest=TEMPLATE,tool=SKIDL,keywords='mems magnetometer',description='InvenSense 9-Axis Motion Sensor, Accelerometer, Gyroscope, Compass, I2C',ref_prefix='U',num_units=1,fplist=['QFN-24*4x4mm_Pitch0.5mm*'],do_erc=True,pins=[
            Pin(num='1',name='CLKIN',do_erc=True),
            Pin(num='3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='AUX_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AUX_SCL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='AD0',do_erc=True),
            Pin(num='10',name='REGOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='CPOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='FSYNC',do_erc=True),
            Pin(num='12',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='SCL',do_erc=True),
            Pin(num='24',name='SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MPU-9250',dest=TEMPLATE,tool=SKIDL,keywords='mems magnetometer',description='InvenSense 9-Axis Motion Sensor, Accelerometer, Gyroscope, Compass, I2C/SPI',ref_prefix='U',num_units=1,fplist=['QFN-24*3x3mm_Pitch0.4mm*'],do_erc=True,pins=[
            Pin(num='1',name='RESV_VDDIO',do_erc=True),
            Pin(num='6',name='AUX_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AUX_SCL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='AD0/MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='REGOUT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='RESV_GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='FSYNC',do_erc=True),
            Pin(num='12',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='~CS',do_erc=True),
            Pin(num='13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='SCL/SCLK',do_erc=True),
            Pin(num='24',name='SDA/MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='MPXA6115A',dest=TEMPLATE,tool=SKIDL,keywords='absolute pressure sensor',description='Absolute pressure sensor, 15 to 115kPa, analog output, integrated signal conditioning, temperature compensated, media resistant gel, SSO package',ref_prefix='U',num_units=1,do_erc=True,aliases=['MPXAZ6115A', 'MPXH6115A', 'MPXHZ6115A'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='Vcc',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='PT100',dest=TEMPLATE,tool=SKIDL,keywords='platinum temperature sensor RTD',description='PT500 platinum temperature sensor (RTD)',ref_prefix='TH',num_units=1,fplist=['TO?92*', 'PIN?ARRAY*', 'bornier*', 'Terminal?Block*', 'SOD70*', 'R*1206*', 'R*0805*'],do_erc=True,aliases=['PT500', 'PT1000'],pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='SHT1x',dest=TEMPLATE,tool=SKIDL,keywords='digital temperature humidity sensor',description='Temperature and humidity module',ref_prefix='U',num_units=1,fplist=['SHT1x'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='DATA',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='SCK',do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TLV493D',dest=TEMPLATE,tool=SKIDL,keywords='magnetic field i2c',description='Low power 3D magnetic sensor, I2C interface, SOT23-6 package',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='SCL/INT',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='SDA/ADDR',func=Pin.BIDIR,do_erc=True)]),
        Part(name='TMP20AIDCK',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Analog thermistor temperature sensor, ±2.5C accuracy, -55C to +130C, SC-70-5 package',ref_prefix='U',num_units=1,fplist=['SC?70*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TMP20AIDRL',dest=TEMPLATE,tool=SKIDL,keywords='temperature sensor thermistor',description='Analog thermistor temperature sensor, ±2.5C accuracy, -55C to +130C, SOT-563-6 package',ref_prefix='U',num_units=1,fplist=['SOT?563*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='Vout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='Vdd',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='TMP411',dest=TEMPLATE,tool=SKIDL,keywords='Temperature sensor remote local i2c',description='- Remote and Local TEMPERATURE SENSOR',ref_prefix='U',num_units=1,fplist=['SOIC', 'MSOP', 'SO'],do_erc=True,pins=[
            Pin(num='1',name='V+',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='D+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='D-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='~TERM',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~ALERT',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='7',name='SDA',func=Pin.OPENCOLL,do_erc=True),
            Pin(num='8',name='SCL',func=Pin.OPENCOLL,do_erc=True)]),
        Part(name='ZXCT1009',dest=TEMPLATE,tool=SKIDL,keywords='High side current sensor monitor shunt',description='High side current sensor, SOT-23',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='Vs-',do_erc=True),
            Pin(num='2',name='Vs+',do_erc=True),
            Pin(num='3',name='Iout',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='ZXCT1107',dest=TEMPLATE,tool=SKIDL,keywords='High side current sensor monitor shunt',description='High side current sensor, SOT-23',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='S+',do_erc=True),
            Pin(num='2',name='S-',do_erc=True),
            Pin(num='3',name='Out',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='ZXCT1109',dest=TEMPLATE,tool=SKIDL,keywords='High side current sensor monitor shunt',description='High side current sensor, SOT-23',ref_prefix='U',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='S-',do_erc=True),
            Pin(num='2',name='S+',do_erc=True),
            Pin(num='3',name='Out',func=Pin.OUTPUT,do_erc=True)])])


#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

"""
Import this file to reconfigure SKiDL for doing SPICE simulations.
"""

from skidl import *

# PySpice only works with Python 3, so don't set up SPICE simulation for Python 2.
try:
    from PySpice import *
    from PySpice.Unit import *
    from .libs.pyspice_sklib import *
    from .tools.spice import *
except ImportError:
    pass
else:
    _splib = SchLib('pyspice', tool=SKIDL)  # Read-in the SPICE part library.

    set_default_tool(SPICE)     # Set the library format for reading SKiDL libraries.

    set_net_bus_prefixes('N', 'B')  # Use prefixes with no odd characters for SPICE.

    GND = gnd = Net('0')  # Instantiate the default ground net for SPICE.

    # Place all the PySpice parts into the namespace so they can be instantiated easily.
    _this_module = sys.modules[__name__]
    for p in _splib.get_parts():
        # Add the part name to the module namespace.
        setattr(_this_module, p.name, p)
        # Add all the part aliases to the module namespace.
        try:
            for alias in p.aliases:
                setattr(_this_module, alias, p)
        except AttributeError:
            pass



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

bosch = SchLib(tool=SKIDL).add_parts(*[
        Part(name='BMF055',dest=TEMPLATE,tool=SKIDL,keywords='9-axis motion sensor IMU SAMD20 ARM Cortex-M0+',description='Custom programmable 9-axis motion sensor',ref_prefix='U',num_units=1,fplist=['LGA-28*'],do_erc=True,pins=[
            Pin(num='1',name='PB03(ACC_GYRO_INT2)',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='PB02',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PB01',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='PB00',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='(SWDIO)PA31',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='(SWCLK)PA30',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='CAP',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PA28',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB16',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='~RESET',do_erc=True),
            Pin(num='21',name='(MISO)PA19',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='(GYRO_CSB)PA27',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='(ACC_MAG_CSB)PA18',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PB23(ACC_GYRO_INT1)',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='(SCLK)PA17',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PA24',do_erc=True),
            Pin(num='24',name='(MOSI)PA16',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PA23',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='GNDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='PA22',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PA01',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PA21',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PA00',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PA20',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDDIO',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='PB17',func=Pin.BIDIR,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

hc11 = SchLib(tool=SKIDL).add_parts(*[
        Part(name='MC68HC11A8CC',dest=TEMPLATE,tool=SKIDL,keywords='HC11 MCU Microcotroller',description='8K ROM, 256B RAM, 512B EEPROM',ref_prefix='U',num_units=1,do_erc=True,aliases=['MC68HC11A7CC', 'MC68HC11A1CC', 'MC68HC11A0CC'],pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='MODB',do_erc=True),
            Pin(num='3',name='MODA',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='AS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='E',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='R/W',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='EXTAL',do_erc=True),
            Pin(num='8',name='XTAL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='AD0/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD1/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='RXD/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PA4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='A10/PB2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='50',name='PE7',do_erc=True),
            Pin(num='11',name='AD2/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TXD/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PA3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='41',name='A9/PB1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='51',name='VRL',do_erc=True),
            Pin(num='12',name='AD3/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='MIS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PA2',do_erc=True),
            Pin(num='42',name='A8/PB0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='52',name='VRH',do_erc=True),
            Pin(num='13',name='AD4/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='MOS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PA1',do_erc=True),
            Pin(num='43',name='PE0',do_erc=True),
            Pin(num='14',name='AD5/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SCK/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PA0',do_erc=True),
            Pin(num='44',name='PE4',do_erc=True),
            Pin(num='15',name='AD6/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SS/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='A15/PB7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='45',name='PE1',do_erc=True),
            Pin(num='16',name='AD7/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='A14/PB6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='46',name='PE5',do_erc=True),
            Pin(num='17',name='~RESET',do_erc=True),
            Pin(num='27',name='PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='A13/PB5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='47',name='PE2',do_erc=True),
            Pin(num='18',name='~XIRQ',do_erc=True),
            Pin(num='28',name='PA6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='A12/PB4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='48',name='PE6',do_erc=True),
            Pin(num='19',name='~IRQ',do_erc=True),
            Pin(num='29',name='PA5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='A11/PB3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='49',name='PE3',do_erc=True)]),
        Part(name='MC68HC11F1CC',dest=TEMPLATE,tool=SKIDL,keywords='HC11 MCU Microcontroller',description='ROMless, 1K RAM, 512B EEPROM, PLCC-68',ref_prefix='U',num_units=1,fplist=['PLCC-68*'],do_erc=True,pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='MODB',do_erc=True),
            Pin(num='3',name='MODA',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='E',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='R/W',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='EXTAL',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='XTAL',do_erc=True),
            Pin(num='8',name='4XOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='D0/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='D1/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='CSPROG/PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='MIS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='A8/PB0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='60',name='PE4',do_erc=True),
            Pin(num='11',name='D2/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='CSGEN/PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='MOS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='A7/PF7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='61',name='PE1',do_erc=True),
            Pin(num='12',name='D3/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CSIO1/PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='SCK/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='A6/PF6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='62',name='PE5',do_erc=True),
            Pin(num='13',name='D4/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='CSIO2/PG4',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SS/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='A15/PB7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='53',name='A5/PF5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='63',name='PE2',do_erc=True),
            Pin(num='14',name='D5/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PG3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='44',name='A14/PB6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='54',name='A4/PF4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='64',name='PE6',do_erc=True),
            Pin(num='15',name='D6/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PG2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='A13/PB5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='55',name='A3/PF3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='65',name='PE3',do_erc=True),
            Pin(num='16',name='D7/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PG1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='A12/PB4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='56',name='A2/PF2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='66',name='PE7',do_erc=True),
            Pin(num='17',name='~RESET',do_erc=True),
            Pin(num='27',name='PG0',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='A11/PB3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='57',name='A1/PF1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='67',name='VRL',do_erc=True),
            Pin(num='18',name='~XIRQ',do_erc=True),
            Pin(num='28',name='RXD/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='A10/PB2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='58',name='A0/PF0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='68',name='VRH',do_erc=True),
            Pin(num='19',name='~IRQ',do_erc=True),
            Pin(num='29',name='TXD/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='A9/PB1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='59',name='PE0',do_erc=True)])])


import pytest
from skidl import *
from .setup_teardown import *

def test_name_1():
    vreg1 = Part('xess.lib', '1117')
    assert vreg1.ref == 'U1'
    vreg1.ref = 'U1'
    assert vreg1.ref == 'U1'
    bus1 = Bus(None)
    assert bus1.name == 'B$1'
    bus1 = Bus('B1')
    assert bus1.name == 'B1'
    bus1.name = 'B1'
    assert bus1.name == 'B1'

def test_name_2():
    b = Bus('A',2)
    for n in b:
        n += Pin()
    n = Net('A0')
    n += Pin()
    net_names = [n.name for n in default_circuit.nets]
    unique_net_names = set(net_names)
    assert len(unique_net_names) == len(net_names)

def test_name_3():
    n = Net('A0')
    n += Pin()
    b = Bus('A',2)
    for n in b:
        n += Pin()
    net_names = [n.name for n in default_circuit.nets]
    unique_net_names = set(net_names)
    assert len(unique_net_names) == len(net_names)



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

nordicsemi = SchLib(tool=SKIDL).add_parts(*[
        Part(name='NRF8001',dest=TEMPLATE,tool=SKIDL,keywords='BLE, bluetooth',description='BLE chip from Nordic Semiconductor',ref_prefix='U',num_units=1,fplist=['QFN32'],do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='DEC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DEC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='XL2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='XL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='ACTIVE',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='TXD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='RXD',do_erc=True),
            Pin(num='20',name='VDD_PA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='30',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='SCK',do_erc=True),
            Pin(num='21',name='ANT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='REQN',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ANT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='DCC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='MOSI',do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='GND_PAD',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='MISO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='24',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='N/C',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='25',name='IREF',do_erc=True),
            Pin(num='16',name='RDYN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='XC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='XC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='RESET',do_erc=True),
            Pin(num='29',name='AVDD',func=Pin.PWRIN,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

supertex = SchLib(tool=SKIDL).add_parts(*[
        Part(name='CL220K4-G',dest=TEMPLATE,tool=SKIDL,keywords='Constant Current LED Driver IC',description='Temperature Compensated Constant Current LED IC, D-PAK',ref_prefix='U',num_units=1,fplist=['TO-252*', 'DPAK*'],do_erc=True,pins=[
            Pin(num='1',name='VA',do_erc=True),
            Pin(num='2',name='VB',do_erc=True)]),
        Part(name='CL220N5-G',dest=TEMPLATE,tool=SKIDL,keywords='Constant Current LED Driver IC',description='Temperature Compensated Constant Current LED IC, TO-220',ref_prefix='U',num_units=1,fplist=['TO-220*'],do_erc=True,pins=[
            Pin(num='1',name='VA',do_erc=True),
            Pin(num='2',name='VB',do_erc=True)]),
        Part(name='HV100K5-G',dest=TEMPLATE,tool=SKIDL,keywords='Hot-Swap Current Limiter',description='Hot-Swap Current Limiter Controller, SOT223',ref_prefix='U',num_units=1,fplist=['SOT-223*'],do_erc=True,aliases=['HV101K5-G'],pins=[
            Pin(num='1',name='VPP',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='VNN',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='GATE',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HV9921N8-G',dest=TEMPLATE,tool=SKIDL,keywords='CC LED Driver High Voltage',description='3pin Constant Current 30mA LED Driver, SOT89',ref_prefix='U',num_units=1,fplist=['SOT*'],do_erc=True,aliases=['HV9922N8-G', 'HV9923N8-G'],pins=[
            Pin(num='1',name='D',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VDD',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HV9925SG-G',dest=TEMPLATE,tool=SKIDL,keywords='Programmable Current LED Lamp Driver High Voltage',description='Programmable Current LED Lamp Driver, SO8 w/Heat Slug',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='Rs',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='PWMD',do_erc=True),
            Pin(num='4',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='6',name='D',do_erc=True),
            Pin(num='7',name='D',do_erc=True),
            Pin(num='8',name='D',do_erc=True)]),
        Part(name='HV9930LG-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck-Boost LED Lamp Driver High Voltage',description='Boost-Buck LED Lamp Driver, SO8',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='VIN',do_erc=True),
            Pin(num='2',name='CS1',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='CS2',do_erc=True),
            Pin(num='8',name='REF',do_erc=True)]),
        Part(name='HV9931LG-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck-Boost LED Lamp Driver High Voltage PFC',description='PFC Boost-Buck LED Lamp Driver, SO8',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='VIN',do_erc=True),
            Pin(num='2',name='CS1',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='CS2',do_erc=True),
            Pin(num='8',name='REF',do_erc=True)]),
        Part(name='HV9961LG-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck LED Lamp Driver High Voltage Average CC',description='Buck LED Lamp Driver Average-Mode Constant Current, SO8',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='VIN',do_erc=True),
            Pin(num='2',name='CS',do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='7',name='LD',do_erc=True),
            Pin(num='8',name='RT',do_erc=True)]),
        Part(name='HV9961NG-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck LED Lamp Driver High Voltage Average CC',description='Buck LED Lamp Driver Average-Mode Constant Current, SO16',ref_prefix='U',num_units=1,fplist=['SO*', 'SOIC*'],do_erc=True,pins=[
            Pin(num='1',name='VIN',do_erc=True),
            Pin(num='4',name='CS',do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='13',name='LD',do_erc=True),
            Pin(num='14',name='RT',do_erc=True)]),
        Part(name='HV9967BK7-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck LED Lamp Driver Low Voltage Average CC',description='Buck LED Lamp Driver Average-Mode Constant Current, DFN8 (3x3mm)',ref_prefix='U',num_units=1,fplist=['DFN*'],do_erc=True,pins=[
            Pin(num='1',name='SW',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='Rs',do_erc=True),
            Pin(num='3',name='PGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='RT',do_erc=True),
            Pin(num='7',name='AGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VDD',func=Pin.PWROUT,do_erc=True)]),
        Part(name='HV9967BMG-G',dest=TEMPLATE,tool=SKIDL,keywords='Buck LED Lamp Driver Low Voltage Average CC',description='Buck LED Lamp Driver Average-Mode Constant Current, MSOP8',ref_prefix='U',num_units=1,fplist=['MSOP*'],do_erc=True,pins=[
            Pin(num='1',name='SW',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='Rs',do_erc=True),
            Pin(num='3',name='PGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='RT',do_erc=True),
            Pin(num='7',name='AGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VDD',func=Pin.PWROUT,do_erc=True)]),
        Part(name='HV9972LG-G',dest=TEMPLATE,tool=SKIDL,keywords='Isolated LED Lamp Driver High Voltage CC',description='Isolated LED Lamp Driver Constant Current, SO8',ref_prefix='U',num_units=1,fplist=['SOIC*', 'SO*'],do_erc=True,pins=[
            Pin(num='1',name='BIAS',do_erc=True),
            Pin(num='2',name='VIN',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VD',do_erc=True),
            Pin(num='4',name='PWMD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='CS',do_erc=True),
            Pin(num='6',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='GATE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VDD',func=Pin.PWROUT,do_erc=True)]),
        Part(name='LR8K4-G',dest=TEMPLATE,tool=SKIDL,keywords='High-Voltage Regulator Adjustable Positive',description='30mA 450V High-Voltage Linear Regulator (Adjustable), TO-252 (D-PAK)',ref_prefix='U',num_units=1,fplist=['TO-252*', 'DPAK*'],do_erc=True,pins=[
            Pin(num='1',name='IN',do_erc=True),
            Pin(num='2',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='3',name='ADJ',do_erc=True)]),
        Part(name='LR8N3-G',dest=TEMPLATE,tool=SKIDL,keywords='High-Voltage Regulator Adjustable Positive',description='30mA 450V High-Voltage Linear Regulator (Adjustable), TO-92',ref_prefix='U',num_units=1,fplist=['TO-92*'],do_erc=True,pins=[
            Pin(num='1',name='IN',do_erc=True),
            Pin(num='2',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='3',name='ADJ',do_erc=True)]),
        Part(name='LR8N8-G',dest=TEMPLATE,tool=SKIDL,keywords='High-Voltage Regulator Adjustable Positive',description='30mA 450V High-Voltage Linear Regulator (Adjustable), SOT-89',ref_prefix='U',num_units=1,fplist=['SOT*'],do_erc=True,pins=[
            Pin(num='1',name='IN',do_erc=True),
            Pin(num='2',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='3',name='ADJ',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

leds = SchLib(tool=SKIDL).add_parts(*[
        Part(name='LED_Cree_XHP50_12V',dest=TEMPLATE,tool=SKIDL,keywords='led diode',description='XLamp® XHP50 LED, 12V footprint (all 4 LEDs in series)',ref_prefix='D',num_units=1,fplist=['LED?CREE?XHP50?12V*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='PAD',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LED_Cree_XHP50_6V',dest=TEMPLATE,tool=SKIDL,keywords='led diode',description='XLamp® XHP50 LED, 6V footprint (2x2 serial LEDs in parallel)',ref_prefix='D',num_units=1,fplist=['LED?CREE?XHP50?6V*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='PAD',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LED_Cree_XHP70_12V',dest=TEMPLATE,tool=SKIDL,keywords='led diode',description='XLamp® XHP70 LED, 12V footprint (all 4 LEDs in series)',ref_prefix='D',num_units=1,fplist=['LED?CREE?XHP70?12V*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='PAD',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LED_Cree_XHP70_6V',dest=TEMPLATE,tool=SKIDL,keywords='led diode',description='XLamp® XHP70 LED, 6V footprint (2x2 serial LEDs in parallel)',ref_prefix='D',num_units=1,fplist=['LED?CREE?XHP70?6V*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='PAD',func=Pin.PASSIVE,do_erc=True)])])


import pytest
from skidl import *
from .setup_teardown import *

def test_net_merge_1():
    a = Net('A')
    b = Net('B')
    a += 5 * Pin()
    assert len(a) == 5
    b += Pin(), Pin(), Pin()
    assert len(b) == 3
    a += b
    assert len(a) == 8



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

ir = SchLib(tool=SKIDL).add_parts(*[
        Part(name='AUIPS7111S',dest=TEMPLATE,tool=SKIDL,keywords='Current Sense,High Side Switch',description='Current Sense With High Side Switch 24V/30A, D2PAK-5L',ref_prefix='U',num_units=1,fplist=['TO-263*'],do_erc=True,pins=[
            Pin(num='1',name='IN',do_erc=True),
            Pin(num='2',name='IFB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='OUT',func=Pin.PWROUT,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.PWROUT,do_erc=True)]),
        Part(name='AUIPS7121R',dest=TEMPLATE,tool=SKIDL,keywords='Current Sense, High Side Switch',description='Current Sense With High Side Switch, 24V/50A, DPAK-5L',ref_prefix='U',num_units=1,fplist=['TO-252*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='IN',do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='IFB',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.PWROUT,do_erc=True)]),
        Part(name='IRS2092',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver Class D',description='Protected Class D Audio Amplifier Half-Bridge Gate Driver, With PWM Modulator, Output Current 1.0/1.2A, +/-100V, PDIP-16/SOIC-16',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x9.9mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='VAA',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='IN-',do_erc=True),
            Pin(num='4',name='COMP',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='CSD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VREF',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='OCSET',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='DT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='VB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='CSH',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IRS20957S',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver Class D',description='Protected Class D Audio Amplifier Half-Bridge Gate Driver, Output Current 1.0/1.2A, +/-100V, SOIC-16',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x9.9mm*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='CSD',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='IN',do_erc=True),
            Pin(num='4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='VREF',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='OCSET',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='DT',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='13',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='14',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='VB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='CSH',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IR2104',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver',description='High and Low Side Gate Driver, Output Current 130/270mA, PDIP-8 , SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='IN',do_erc=True),
            Pin(num='3',name='~SD',do_erc=True),
            Pin(num='4',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IR2106',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver',description='High and Low Side Driver, 600V operation, Output Current 120/200mA, PDIP-8 , SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*', 'DIP*'],do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HIN',do_erc=True),
            Pin(num='3',name='LIN',do_erc=True),
            Pin(num='4',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IR2110',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver',description='High and Low Side Gate Driver, Output Current 2.0/2.0A, PDIP-14 , SOIC-14',ref_prefix='U',num_units=1,fplist=['SOIC*7.5x10.3mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,aliases=['IR2113'],pins=[
            Pin(num='1',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='VB',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='HIN',do_erc=True),
            Pin(num='11',name='SD',do_erc=True),
            Pin(num='12',name='LIN',do_erc=True),
            Pin(num='13',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='NC',func=Pin.NOCONNECT,do_erc=True)]),
        Part(name='IRS2181',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver',description='High and Low Side Gate Driver, Output Current 1.4/1.8A, PDIP-8 , SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='HIN',do_erc=True),
            Pin(num='2',name='LIN',do_erc=True),
            Pin(num='3',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IRS2186',dest=TEMPLATE,tool=SKIDL,keywords='gate driver',description='High and Low Side Gate Driver, 600V operation, 4A output current',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='HIN',do_erc=True),
            Pin(num='2',name='LIN',do_erc=True),
            Pin(num='3',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='IRS21867S',dest=TEMPLATE,tool=SKIDL,keywords='Gate Driver',description='High and Low Side Gate Driver, Output Current 4.0/4.0A, 600V, SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HIN',do_erc=True),
            Pin(num='3',name='LIN',do_erc=True),
            Pin(num='4',name='COM',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VB',func=Pin.PWRIN,do_erc=True)])])


import pytest
from skidl import *
from .setup_teardown import *

def test_missing_lib():
    # Sometimes, loading a part from a non-existent library doesn't throw an
    # exception until the second time it's tried. This detects that error.
    set_query_backup_lib(False)  # Don't allow searching backup lib that might exist from previous tests.
    with pytest.raises(Exception):
        a = Part('crap', 'R')
    with pytest.raises(Exception):
        b = Part('crap', 'C')

def test_lib_import_1():
    lib = SchLib('xess.lib')
    assert len(lib) > 0

def test_lib_import_2():
    lib = SchLib('device')

def test_lib_export_1():
    lib = SchLib('device')
    lib.export('my_device', tool=SKIDL)
    my_lib = SchLib('my_device', tool=SKIDL)
    assert len(lib) == len(my_lib)

def test_lib_creation_1():
    lib = SchLib()
    prt1 = SkidlPart(name='Q', dest=TEMPLATE)
    lib += prt1
    lib += prt1  # Duplicate library entries are not added.
    assert(len(lib.parts) == 1)
    assert(not lib.get_parts(name='QQ')) # Part not in library.
    prt2 = SkidlPart(name='QQ', dest=TEMPLATE)
    prt2.add_pins(Pin(num=1,name='Q1',func=Pin.TRISTATE), Pin(num=2,name='Q2',func=Pin.PWRIN))
    lib += prt2
    prt2.add_pins(Pin(num=3,name='Q1',func=Pin.PWROUT))
    assert(len(lib.parts) == 2)
    assert(lib['Q'].name == 'Q')
    assert(len(lib['Q'].pins) == 0)
    assert(lib['QQ'].name == 'QQ')
    assert(len(lib['QQ'].pins) == 2)

def test_backup_1():
    a = Part('device','R',footprint='null')
    b = Part('device','C',footprint='null')
    c = Part('device','L',footprint='null')
    generate_netlist(do_backup=True)  # This creates the backup parts library.
    default_circuit.reset()
    set_query_backup_lib(True) # FIXME: this is already True by default!
    a = Part('crap','R',footprint='null')
    b = Part('crap','C',footprint='null')
    generate_netlist()

def test_lib_1():
    lib_kicad = SchLib('device')
    lib_kicad.export('device')
    SchLib.reset()
    lib_skidl = SchLib('device', tool=SKIDL)
    assert(len(lib_kicad) == len(lib_skidl))
    SchLib.reset()
    set_default_tool(SKIDL)
    set_query_backup_lib(False)
    a = Part('device','R')
    assert a.tool == SKIDL
    b = Part('device','L')
    assert b.tool == SKIDL
    c = Part('device','C')
    assert c.tool == SKIDL

def test_non_existing_lib_cannot_be_loaded():
    for tool in ALL_TOOLS:
        with pytest.raises(Exception):
            lib = SchLib("non-existing", tool = tool)

def test_part_from_non_existing_lib_cannot_be_instantiated():
    for tool in ALL_TOOLS:
        with pytest.raises(Exception):
            part = Part("non-existing", "P", tool = tool)
